==> pleroma-bot-1.1.0.tar.gz: pleroma-bot-1.1.0/docs/contribute/contributing.md <==
---
hide:
  - navigation
  - toc
---

# Contributing

## Funding
[![Donate using Liberapay](https://liberapay.com/assets/widgets/donate.svg)](https://liberapay.com/robertoszek/donate) [![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/robertoszek) [<img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Buy Me A Coffee" style="height: 30px !important;" >](https://www.buymeacoffee.com/robertoszek) [<img src="https://c5.patreon.com/external/logo/become_a_patron_button.png" alt="Become a Patron!" style="height: 30px !important;" >](https://www.patreon.com/bePatron?u=19859432)

| Type                              | Address                                                                                               |
|:----------------------------------|-------------------------------------------------------------------------------------------------------|
| :fontawesome-brands-monero: XMR   | ```899StGytrpBSq6B9i7ca3iKb6pMM77VkcMxoTquAMJSPSq4HTJtavp5Qe4EFtmAuo74vYWDZ1qWnA2s6D8NZ19NZ8eaASBy``` |
| :fontawesome-brands-bitcoin: BTC  | ```bc1qvwnv67gtslll65ya5pa93nqfnrvp4j8r9kdz5k```                                                      |
| :fontawesome-brands-ethereum: ETH | ```0x16f48dc8b7df603da2888e7708f495091080df7d```                                                      |

## Code

Patches, pull requests, and bug reports are more than [welcome](https://github.com/robertoszek/pleroma-bot/issues/new/choose), please keep the style consistent with the original source.

## Translations

We're looking for translators for other languages! 

You can get the PO template from [here](https://github.com/robertoszek/pleroma-bot/blob/develop/pleroma_bot/locale/pleroma_bot.pot) and create a translation with an editor such as [Poedit](https://poedit.net/).

| Language       | Status                                                  | Translator                                    |
|:--------------:|:-------------------------------------------------------:|:---------------------------------------------:|
| en_US          | :octicons-check-circle-24: Complete                     | [robertoszek](https://github.com/robertoszek) |
| es_ES          | :octicons-check-circle-24: Complete                     | [robertoszek](https://github.com/robertoszek) |

==> pleroma-bot-1.2.0.tar.gz: pleroma-bot-1.2.0/docs/contribute/contributing.md <==
---
hide:
  - navigation
  - toc
---

# Contributing

## Funding
[![Donate using Liberapay](https://liberapay.com/assets/widgets/donate.svg)](https://liberapay.com/robertoszek/donate) [![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/robertoszek) [<img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Buy Me A Coffee" style="height: 30px !important;" >](https://www.buymeacoffee.com/robertoszek) [<img src="https://c5.patreon.com/external/logo/become_a_patron_button.png" alt="Become a Patron!" style="height: 30px !important;" >](https://www.patreon.com/bePatron?u=19859432) [<img src="https://www.paypalobjects.com/webstatic/mktg/logo/pp_cc_mark_37x23.jpg" alt="Donate using PayPal" style="height: 30px !important;">](https://paypal.me/robertoszek)

| Type                              | Address                                                                                               |
|:----------------------------------|-------------------------------------------------------------------------------------------------------|
| :fontawesome-brands-monero: XMR   | ```899StGytrpBSq6B9i7ca3iKb6pMM77VkcMxoTquAMJSPSq4HTJtavp5Qe4EFtmAuo74vYWDZ1qWnA2s6D8NZ19NZ8eaASBy``` |
| :fontawesome-brands-bitcoin: BTC  | ```bc1qvwnv67gtslll65ya5pa93nqfnrvp4j8r9kdz5k```                                                      |
| :fontawesome-brands-ethereum: ETH | ```0x16f48dc8b7df603da2888e7708f495091080df7d```                                                      |

## Code

Patches, pull requests, and bug reports are more than [welcome](https://github.com/robertoszek/pleroma-bot/issues/new/choose), please keep the style consistent with the original source.

## Translations

We're looking for translators for other languages! 

You can get the PO template from [here](https://github.com/robertoszek/pleroma-bot/blob/develop/pleroma_bot/locale/pleroma_bot.pot) and create a translation with an editor such as [Poedit](https://poedit.net/).

| Language       | Status                                                  | Translator                                    |
|:--------------:|:-------------------------------------------------------:|:---------------------------------------------:|
| en_US          | :octicons-check-circle-24: Complete                     | [robertoszek](https://github.com/robertoszek) |
| es_ES          | :octicons-check-circle-24: Complete                     | [robertoszek](https://github.com/robertoszek) |
